# Changelog

<!--next-version-placeholder-->

## v1.3.0 (2022-05-21)
### Feature
* Read/update profile feature ([#2](https://github.com/draganagrbic998/devops_profile_service3/issues/2)) ([`816d9fe`](https://github.com/draganagrbic998/devops_profile_service3/commit/816d9fea4bbc64a33e7360a98491bc338be3c73b))

## v1.2.0 (2022-05-21)
### Feature
* Read/search offers feature ([#1](https://github.com/draganagrbic998/devops_profile_service3/issues/1)) ([`6de0180`](https://github.com/draganagrbic998/devops_profile_service3/commit/6de01809cfe2f82f9c17a438b34231a69463f612))

## v1.1.0 (2022-05-21)
### Feature
* Init profile service ([`a48c1fe`](https://github.com/draganagrbic998/devops_profile_service3/commit/a48c1fee598127b0b557cbb8bcbe3d08bb0c78d3))
